.. _readme_zh:

###################
README 镜像（中文）
###################

该页面用于说明 README 与文档自动同步机制。

- 单一来源文件：``/README_CHINESE.md``
- 生成镜像文件：``/docs/source/readme_zh.md``
- 同步命令：``python scripts/sync_readme_to_docs.py``
- CI 校验命令：``python scripts/sync_readme_to_docs.py --check``

文档渲染内容请查看以下自动生成页面：

- :doc:`generated/installation_zh`
- :doc:`generated/quickstart_zh`
- :doc:`generated/workflow_zh`
- :doc:`generated/matching_zh`
- :doc:`generated/evaluation_zh`
- :doc:`generated/troubleshooting_zh`
- :doc:`generated/faq_zh`
